# List of settings

- `DIRACX_URL`: The URL of the DiracX server.
- `DIRACX_CA_PATH`: The path to the CA certificate bundle.
- `DIRACX_OUTPUT_FORMAT`: The output format for the CLI (RICH or JSON).
- `DIRACX_LOG_LEVEL`: The log level for the CLI (ERROR, WARNING, INFO, or DEBUG).
- `DIRACX_CREDENTIALS_PATH`: The path to the credentials file.
